# encoding: utf-8
# set key、token、pkg_name、platform
from vaassdk.src.vaas import config


class Credentials(object):

    def set_key(self, ak):
        config.ACCESS_KEY = ak

    def set_token(self, token):
        config.ACCESS_TOKEN = token

    def set_pkgname(self, pkg):
        config.PKG_NAME = pkg

    def set_platform(self, platform):
        config.PLATFORM = platform



# encoding: utf-8
import sys
# 测试模块
from vaassdk.src.vaas import report
from vaassdk.src.vaas import credentials


def test_videoshow(report):
    print("\n ###视频曝光上报### \n")
    videoid = 'gjwbEJZnV0MV'  # 视频ID
    referpage = 'channel_100'  # 展现来源，channel_xxx-feed页，vplaypage-相关页
    pos = 1  # 视频在信息流或者相关页出现的位置，从1开始计算
    try:
        ret = report.videoshow(videoid, referpage, pos)
    except Exception:
        raise
    else:
        print(ret)


def test_videoplay(report):
    print("\n ###点击播放上报### \n")
    videoid = 'gjwbEJZnV0MV'  # 视频ID
    referpage = 'channel_100'  # 展现来源，channel_xxx-feed页，vplaypage-相关页
    try:
        ret = report.videoplay(videoid, referpage)
    except Exception:
        raise
    else:
        print(ret)


def test_videoplaytm(report):
    print("\n ###播放时长上报### \n")
    videoid = 'gjwbEJZnV0MV'  # 视频ID
    bt = 1622527513  # 播放开始时间点，单位：秒
    et = 1622527523  # 播放结束时间点，单位：秒
    rt = 0  # 上报原因 0-正常结束 1-提前停止播放
    try:
        ret = report.videoplaytm(videoid, bt, et, rt)
    except Exception:
        raise
    else:
        print(ret)


def test_videofeedback(report):
    print("\n ###视频反馈上报### \n")
    videoid = 'gjwbEJZnV0MV'  # 视频ID
    cpid = 'nJ5vdO8kr8MV'  # 作者ID
    action = 'like'  # 反馈动作：like喜欢，dislike取消喜欢，follow关注
    try:
        ret = report.videofeedback(videoid, cpid, action)
    except Exception:
        raise
    else:
        print(ret)


if __name__ == '__main__':
    # 设置公共参数
    credentials = credentials.Credentials()
    credentials.set_key('')
    # 设备唯一标识，客户端生成
    udid = ''
    report = report.Report(udid)
    # 视频曝光上报
    test_videoshow(report)
    # 点击播放上报
    test_videoplay(report)
    # 播放时长上报
    test_videoplaytm(report)
    # 视频反馈上报
    test_videofeedback(report)



# all vaas api service
from vaassdk.src.vaas import tools
from vaassdk.src.vaas import config

class Vaas():
    def __init__(self, udid):
        self.tool = tools.Tools(udid)
        self.isplay = config.HOST_PROD_PLAY
        self.unplay = config.HOST_PROD

    def feed(self, video_type, channel_id, load_type=0, size=8):
        input = {'video_type': video_type, 'channel_id': channel_id, 'load_type': load_type, 'size': size}
        self.tool.set_input(input)
        ret = self.tool.request_api(self.unplay + config.FEED)
        return ret

    def relation(self, id, size=20):
        input = {'id': id, 'size': size}
        self.tool.set_input(input)
        ret = self.tool.request_api(self.unplay + config.RELATION)
        return ret

    def channels(self):
        ret = self.tool.request_api(self.unplay + config.CHANNELS)
        return ret

    def detail(self, ids, video_type):
        input = {'ids': ids, 'video_type': video_type}
        self.tool.set_input(input)
        ret = self.tool.request_api(self.unplay + config.DETAIL)
        return ret

    def cpinfo(self, id, video_type):
        input = {'id': id, 'video_type': video_type}
        self.tool.set_input(input)
        ret = self.tool.request_api(self.unplay + config.CPINFO)
        return ret

    def cpvideos(self, id, video_type, page=1, size=20):
        input = {'id': id, 'video_type': video_type, 'page': page, 'size': size}
        self.tool.set_input(input)
        ret = self.tool.request_api(self.unplay + config.CPVIDOES)
        return ret

    def play(self, id):
        input = {'id': id}
        self.tool.set_input(input)
        ret = self.tool.request_api(self.isplay + config.PLAY)
        return ret


# report info service
import json
import time
from vaassdk.src.vaas import tools
from vaassdk.src.vaas import config


class Report():
    def __init__(self, udid):
        self.tool = tools.Tools(udid)
        self.url = config.HOST_DATA

    # 视频曝光上报
    def videoshow(self, videoid, referpage, pos):
        body = '{"videoid": "%s", "referpage": "%s", "pos": "%d"}' % (videoid, referpage, pos)
        input = {'event': 'videoshow', 'body': json.loads(body)}
        self.tool.set_input(input)
        ret = self.tool.request_report(self.url)
        return ret

    # 点击播放上报
    def videoplay(self, videoid, referpage):
        body = '{"videoid": "%s", "referpage": "%s", "taskid": "%d"}' % (
        videoid, referpage, int(round(time.time() * 1000)))
        input = {'event': 'videoplay', 'body': json.loads(body)}
        self.tool.set_input(input)
        ret = self.tool.request_report(self.url)
        return ret

    # 播放时长上报
    def videoplaytm(self, videoid, bt, et, rt):
        body = '{"videoid": "%s", "taskid": "%s", "bt": "%d", "et": "%d", "rt": "%d"}' % (
            videoid, int(round(time.time() * 1000)), bt, et, rt)
        input = {'event': 'videoplaytm', 'body': json.loads(body)}
        self.tool.set_input(input)
        ret = self.tool.request_report(self.url)
        return ret

    # 视频反馈上报
    def videofeedback(self, videoid, cpid, action):
        body = '{"videoid": "%s", "cpid": "%s", "action": "%s"}' % (videoid, cpid, action)
        input = {'event': 'videofeedback', 'body': json.loads(body)}
        self.tool.set_input(input)
        ret = self.tool.request_report(self.url)
        return ret



# encoding: utf-8

# 联系一览获取access_key、access_token
ACCESS_KEY = ''  # 一览提供的渠道ak
ACCESS_TOKEN = ''  # 一览提供的渠道token
PKG_NAME = ''  # 应用包名
PLATFORM = 1  # 接入方式

# 请求url
FEED = '/video/feed'  # feed流
CHANNELS = '/video/channels'  # 频道
RELATION = '/video/relation'  # 频道相关
DETAIL = '/video/getvideos'  # 视频详情
CPINFO = '/video/cpinfo'  # 作者详情
CPVIDOES = '/video/cpvideos'  # 作者视频
PLAY = '/vaas/video/play'  # 播放

# 以下常量不需要修改
HOST_PROD = 'http://api.yilanvaas.cn'  # 线上正式域名(播放接口除外)
HOST_PROD_PLAY = 'http://play.yilanvaas.cn'  # 线上正式域名(播放接口)
HOST_DATA = 'http://data.1lan.tv/log?ts=%d&access_key=%s&udid=%s&m=%s'  # 上报相关域名
DATA_BEGION = '13149876'
DATA_END = '98761314'
CONNECT_TIMEOUT = 5
READ_TIMEOUT = 10
DEFAULT_MAX_RETRY_TIMES = 2


# encoding: utf-8
# 测试模块
from vaassdk.src.vaas import credentials
from vaassdk.src.vaas import vaas


def test_channel(vaas):
    print("\n ###获取频道数据### \n")
    try:
        channels = vaas.channels()
    except Exception:
        raise
    else:
        print(channels)


def test_feed(vaas):
    print("\n ###获取视频信息流数据### \n")
    video_type = 1  # 视频类型横屏1，竖屏2
    channel_id = 10175  # 频道id
    load_type = 0  # 拉取类型0-上拉，1-下拉，2-首次刷新（非必传，默认0）
    size = 8  # 页大小，范围 1～8（非必传，默认8）
    try:
        feed = vaas.feed(video_type, channel_id, load_type, size)
    except Exception:
        raise
    else:
        print(feed)


def test_relation(vaas):
    print("\n ###获取相关视频数据### \n")
    id = 'Jy8nbGGXEJjR'  # 视频ID
    size = 20  # 页大小，范围 1～20（非必传，默认20）
    try:
        relation = vaas.relation(id, size)
    except Exception:
        raise
    else:
        print(relation)


def test_cpinfo(vaas):
    print("\n ###获取作者详情### \n")
    id = '28yJYbZwR65k'  # 视频ID
    video_type = 1  # 视频类型横屏1，竖屏2
    # video_type = 2
    try:
        cpInfo = vaas.cpinfo(id, video_type)
    except Exception:
        raise
    else:
        print(cpInfo)


def test_detail(vaas):
    print("\n ###获取视频详情### \n")
    ids = 'gjwbEJZnV0MV,EjVx74kPNoyQ'  # 视频ID，多条用英文逗号隔开
    video_type = 1  # 视频类型横屏1，竖屏2
    # ids = 'eJMeOJN9B5KX,ZVjkOgN0WjGp'
    # video_type = 2
    try:
        detail = vaas.detail(ids, video_type)
    except Exception:
        raise
    else:
        print(detail)


def test_cpvideos(vaas):
    print("\n ###获取作者视频列表### \n")
    id = 'pbjDYWR0P52N'  # 作者ID
    video_type = 1  # 视频类型横屏1，竖屏2
    page = 1  # 页码（非必传，默认1）
    size = 20  # 页大小（非必传，默认20）
    # id = 'RJj017XJvx58'
    # video_type = 2
    try:
        cpVideos = vaas.cpvideos(id, video_type)
    except Exception:
        raise
    else:
        print(cpVideos)


def test_play(vaas):
    print("\n ###获取播放数据### \n")
    id = 'njz3Dn7N1r5V'  # 视频ID
    try:
        plays = vaas.play(id)
    except Exception:
        raise
    else:
        print(plays)


if __name__ == '__main__':
    # 设置公共参数
    credentials = credentials.Credentials()
    credentials.set_key('')
    credentials.set_token('')
    credentials.set_pkgname('')
    credentials.set_platform(2)
    # 设备唯一标识，客户端生成
    udid = ''
    vaas = vaas.Vaas(udid)
    # 获取频道数据
    test_channel(vaas)
    # 获取视频信息流数据
    test_feed(vaas)
    # 获取相关视频数据
    test_relation(vaas)
    # 获取作者详情
    test_cpinfo(vaas)
    # 获取视频详情
    test_detail(vaas)
    # 获取作者视频列表
    test_cpvideos(vaas)
    # 获取播放数据
    test_play(vaas)



# coding=utf-8
# Tools Libs, include generate signature, data encryption and decryption
# pip install pycryptodome
import logging

import hashlib
import base64
import hmac
import json

import requests
from Crypto.Cipher import AES
import time
from vaassdk.src.vaas import config


class Tools(object):
    def __init__(self, udid):
        self.dict = {}
        self.udid = udid

    # 入参以字典形式传入
    def set_input(self, dist):
        self.dict = dist

    # sha256加密获取签名
    def sha256_signature(self, aAesMes, aAccessToken, aTimeStamp):
        message = aAesMes
        secret_key = bytes(aAccessToken + str(aTimeStamp), 'utf-8')
        sign = base64.b64encode(hmac.new(secret_key, message, digestmod=hashlib.sha256).digest())
        return sign

    # 数据加密
    def aes_encrypt(self, aAccessToken, aOriginText):
        key = bytes(aAccessToken, 'utf-8')
        iv = key[0:16]
        aes_padding = AES.block_size
        plain_text = aOriginText
        amount_to_pad = aes_padding - (len(plain_text) % aes_padding)
        if amount_to_pad == 0:
            amount_to_pad = aes_padding
        plain_text = bytes(plain_text + chr(amount_to_pad) * amount_to_pad, 'utf-8')
        cryptor = AES.new(key, AES.MODE_CBC, iv)
        en_text = base64.b64encode(cryptor.encrypt(plain_text))
        return en_text

    # 数据解密
    def aes_decrypt(self, aAESData, aToken):
        if aAESData == "":
            logging.warning("the data is empty")
            return []

        key = bytes(aToken, 'utf-8')
        iv = key[0:16]
        en_text = aAESData
        cryptor = AES.new(key, AES.MODE_CBC, iv)
        plain_text = cryptor.decrypt(base64.b64decode(en_text))
        plain_text = bytes.decode(plain_text[:-plain_text[-1]])
        logging.info("aes decrypt data:" + plain_text)
        data_array = json.loads(plain_text)
        logging.info("json_load data:" + str(data_array))
        return data_array

    # vaas请求各个参数封装
    def request_api(self, aUrl):
        # 获取config中的key和token
        access_key = config.ACCESS_KEY
        access_token = config.ACCESS_TOKEN
        # 判断key和token是否有值
        if access_key == '' or access_token == '' or (len(access_key) != 12 and len(access_key) != 25):
            raise Exception("access_key或access_token格式错误")
        # 获取时间戳
        curTimeStamp = int(round(time.time() * 1000))
        # 获取参数
        textmessage = self.get_vaasparam()
        # AES加密参数
        aes_sec_mes = self.aes_encrypt(access_token, textmessage)
        # sha256签名
        sha256_sig = self.sha256_signature(aes_sec_mes, access_token, curTimeStamp)
        # 发送请求并解析
        return self.request_v2(access_token, aUrl, access_key, curTimeStamp, sha256_sig, aes_sec_mes)

    # 数据上报http请求
    def request_report(self, aUrl):
        # 获取完整url
        aUrl = self.report_url(aUrl)
        # 获取参数
        textmessage = self.get_reportparam()
        response = requests.request("POST", aUrl, data=textmessage)
        logging.info("response data is:" + response.text)
        resDic = json.loads(response.text)
        if resDic['code'] == 0 or resDic['code'] == '0':
            if 'data' in resDic:
                return resDic['msg']
        else:
            logging.fatal("request is fail")
            raise Exception(resDic['msg'])

    # 数据上报get url拼接
    def report_url(self, aUrl):
        curTimeStamp = int(time.time())
        access_key = config.ACCESS_KEY
        if access_key == '' or (len(access_key) != 12 and len(access_key) != 25):
            raise Exception("access_key格式错误")
        udid = self.udid
        md5_sig = self.md5_signature(curTimeStamp, access_key, udid)
        aUrl = aUrl % (curTimeStamp, access_key, udid, md5_sig)
        return aUrl

    # 数据上报md5加密
    def md5_signature(self, ts, access_key, udid):
        data = config.DATA_BEGION + str(ts) + access_key + udid + config.DATA_END
        md5_sign = hashlib.md5(data.encode(encoding='UTF-8')).hexdigest()
        return md5_sign

    # vaas http请求
    def request_v2(self, aToken, aURL, aAccessKey, aTimestamp, aSignature, aAESData):
        payload = '{"access_key": "%s","params": "%s","sign": "%s","timestamp":%d}' % (
            aAccessKey, bytes.decode(aAESData), bytes.decode(aSignature), aTimestamp)
        logging.info("request data is:" + payload)
        headers = {"X-YL-KEY": aAccessKey, "X-YL-TIMESTAMP": str(aTimestamp)}
        response = requests.request("POST", aURL, data=payload, headers=headers)
        logging.info("response data is:" + response.text)
        # 解析返回值
        resDic = json.loads(response.text)
        if resDic['code'] == 200 or resDic['code'] == '200':
            if 'data' in resDic:
                return self.aes_decrypt(resDic['data'], aToken)
        else:
            logging.fatal("request is fail" + str(resDic))
            raise Exception(resDic['msg'])

    # vaas params拼接
    def get_vaasparam(self):
        # 公共入参
        defult = {'udid': self.udid, 'pkg_name': config.PKG_NAME, 'platform': config.PLATFORM}
        # 方法传参
        input = self.dict
        input.update(defult)
        params = json.dumps(input)
        return params

    # report params拼接
    def get_reportparam(self):
        # 公共入参
        defult = {"access_key": config.ACCESS_KEY,
                  "udid": self.udid,
                  "sn": int(round(time.time() * 1000))
                  }
        # 方法传参
        input = self.dict
        input.update(defult)
        params = json.dumps(input)
        return params



from setuptools import setup, find_packages

setup(
    name="vaassdk",
    version="1.0.3",
    description="vaassdk",
    author="yilan",
    url="https://github.com/yilanyun/vaas-sdk-python.git",
    packages=find_packages()
)
